<?php
/*
Plugin Name: TranslatePress - Only translate certain paths
Plugin URI: https://translatepress.com
Description: Only translate url's that contain paths from WordPress -> Settings -> TranslatePress - Only Translate Paths
Author: Cristian Antohe
Version: 0.1
*/


////////////////////////////////////////////////////////////////////
// Only Translate certain paths

add_action( 'admin_menu', 'trpc_otp_add_admin_menu' );
add_action( 'admin_init', 'trpc_otp_settings_init' );


function trpc_otp_add_admin_menu(  ) {

add_options_page( 'TranslatePress Only Translate Some Paths', 'TranslatePress - Only Translate Paths', 'manage_options', 'trpc_only_translate_paths', 'trpc_otp_options_page' );

}


function trpc_otp_settings_init(  ) {

register_setting( 'pluginPage', 'trpc_otp_settings' );

add_settings_section(
'trpc_otp_pluginPage_section',
'',
'trpc_otp_settings_section_callback',
'pluginPage'
);

add_settings_field(
'trpc_otp_textarea_field_0',
__( 'Paths', 'trpc_otp' ),
'trpc_otp_textarea_field_0_render',
'pluginPage',
'trpc_otp_pluginPage_section'
);


}


function trpc_otp_textarea_field_0_render(  ) {

$options = get_option( 'trpc_otp_settings' );
?>
<textarea cols='40' rows='5' name='trpc_otp_settings[trpc_otp_textarea_field_0]'><?php echo $options['trpc_otp_textarea_field_0']; ?></textarea>
<?php

}


function trpc_otp_settings_section_callback(  ) {

    echo __( 'Add a path you want translated like "/product/excelent-cup/" on each line.', 'trpc_otp' );

}


function trpc_otp_options_page(  ) {

    ?>
    <form action='options.php' method='post'>

        <h2>TRPC Only Translate Paths</h2>

        <?php
        settings_fields( 'pluginPage' );
        do_settings_sections( 'pluginPage' );
        submit_button();
        ?>

    </form>
    <?php

}

add_action( 'plugins_loaded', 'trpc_exclude_tp_from_pages', -1 );
function trpc_exclude_tp_from_pages(){

    $translate_only_paths_option = get_option('trpc_otp_settings');
    $translate_only_paths = explode("\n", str_replace("\r", "", $translate_only_paths_option['trpc_otp_textarea_field_0'] ) );
    $translate_only_paths[] = '/wp-admin/';

    foreach ( $translate_only_paths as $path ){
        if ( !empty($path) && strpos($_SERVER['REQUEST_URI'], untrailingslashit($path)) !== false ){
            return;
        }
    }

    add_filter('trp_allow_tp_to_run', 'trpc_return_false');
}

function trpc_return_false(){
    return false;
}

// only force custom links in paths that are translatable
add_filter( 'trp_force_custom_links', 'trpc_only_in_translatable_paths', 10, 4);
function trpc_only_in_translatable_paths( $new_url, $url, $TRP_LANGUAGE, $a_href ){

    $translate_only_paths_option = get_option('trpc_otp_settings');
    $translate_only_paths = explode("\n", str_replace("\r", "", $translate_only_paths_option['trpc_otp_textarea_field_0'] ) );
    $translate_only_paths[] = '/wp-admin/';

    foreach ( $translate_only_paths as $path ){
        if (strpos($url, untrailingslashit($path)) !== false ){
            return $new_url;
        }
    }

    return $url;
}

add_filter('trp_href_from_translated_page', 'trpc_transform_every_href_to_default_lang', 10, 2);
function trpc_transform_every_href_to_default_lang($url, $default_lang){
    if ( !class_exists('TRP_Translate_Press') )
        return;

    $translate_only_paths_option = get_option('trpc_otp_settings');
    $translate_only_paths = explode("\n", str_replace("\r", "", $translate_only_paths_option['trpc_otp_textarea_field_0'] ) );
    $translate_only_paths[] = '/wp-admin/';

    foreach ( $translate_only_paths as $path ){
        if (strpos($url, untrailingslashit($path)) !== false ){
            return $url;
        }
    }

    $trp = TRP_Translate_Press::get_trp_instance();
    $url_converter = $trp->get_component('url_converter');

    $new_url = $url_converter->get_url_for_language( $default_lang, $url );

    return $new_url;
}